package com.project.zcustom.service.unit;

import java.util.List;
import java.util.Map;

public interface IPlatBuildingService {
    List<String> getPowerAndWaterMonth();

    List<Map<String, Object>> getAirCondition();

    List<Map<String, Object>> getTarget();

    List<Map<String, Object>> useElectricity();

    List<Map<String, Object>> greenElectricity();

    List<Map<String, Object>> carbon();

    Map<String, Object> energyYear();

    Map<String, Object> powerYear();

    Map<String, Object> waterYear();

    List<Map<String, Object>> frequency();

    Map<String, Object> patrol();

    List<Map<String, Object>> patrolPoint();
}
